<img src="https://cdn.jsdelivr.net/gh/NKID00/redstone-computer-utilities@dev/src/main/resources/assets/rcutil/icon.png" alt="icon" align="right" height="175">

# Redstone Computer Utilities

>  Lightweight and Modular Redstone Computer Debugging Tools.

## Installation

Python 3.7.2 or newer (CPython or PyPy) is required.

```sh
$ pip install redstone-computer-utilities
```

or

```toml
# pyproject.toml
redstone-computer-utilities = "^0.2.0"
```

### Check the GitHub repository [NKID00/redstone-computer-utilities](https://github.com/NKID00/redstone-computer-utilities) for details.